Documentation
¶
Index ¶
Constants ¶
const ( // MimeTypeUnknown is a catch-all for unspecified object type MimeTypeUnknown = "unknown" // MimeTypePDF is a pdf document MimeTypePDF = "pdf" // MimeTypeDocument is a plain-text document MimeTypeDocument = "document" // MimeTypeImage is an image asset MimeTypeImage = "image" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MetaDataV2 ¶ added in v0.2.0
type MetaDataV2 struct {
DisplayName string `json:"display_name"`
MimeType string `json:"mime_type"`
Category string `json:"category"`
Tags []string `json:"tags"`
}
MetaDataV2 is a piece of meta data from a given object after being lensed
type ObjectV2 ¶ added in v0.2.0
type ObjectV2 struct {
// Hash is how you identify the object on its network, ie content hash
Hash string `json:"content_hash"`
// MD is metadata associated with the object
MD MetaDataV2 `json:"meta"`
}
ObjectV2 is a distributed web object (ie, ipld)
Click to show internal directories.
Click to hide internal directories.