Documentation
¶
Overview ¶
Package text handles analyzing textual data for the purpose of meta data extraction
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Analyzer ¶
type Analyzer struct {
TR *textrank.TextRank
Rule parse.Rule
Language convert.Language
Algorithm rank.Algorithm
}
Analyzer is used to analyze and extract meta data from text
func NewTextAnalyzer ¶
NewTextAnalyzer is used to generate our text analyzer
func (*Analyzer) Clear ¶
func (ta *Analyzer) Clear()
Clear is used to reset the data that textrank is parsing
func (*Analyzer) RetrievePhrases ¶
RetrievePhrases is a short wrapper around the FindPhrases function
Click to show internal directories.
Click to hide internal directories.