Documentation
¶
Index ¶
- type APIOpts
- type ConfigOpts
- type Object
- type Service
- func (s *Service) Get(keyname string) ([]byte, error)
- func (s *Service) KeywordSearch(keywords []string) ([]models.Object, error)
- func (s *Service) Magnify(hash string, reindex bool) (metadata *models.MetaData, err error)
- func (s *Service) Store(name string, meta *models.MetaData) (*Object, error)
- func (s *Service) Update(id uuid.UUID, name string, meta *models.MetaData) (*Object, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConfigOpts ¶
type ConfigOpts struct {
UseChainAlgorithm bool
DataStorePath string
ModelsPath string
TesseractConfigPath string
API APIOpts
}
ConfigOpts are options used to configure the lens service
type Object ¶
type Object struct {
ContentHash string `json:"lens_object_content_hash"`
LensID uuid.UUID `json:"lens_id"`
}
Object is the response from a successfuly lens indexing operation
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service contains the various components of Lens
func NewService ¶
func NewService(opts ConfigOpts, cfg config.TemporalConfig, rm rtfs.Manager, ia images.TensorflowAnalyzer, ss search.Searcher, logger *zap.SugaredLogger) (*Service, error)
NewService is used to generate our Lens service
func (*Service) KeywordSearch ¶
KeywordSearch is used to search by keyword
func (*Service) Magnify ¶
Magnify is used to examine a given content hash, determine if it's parsable and returned the summarized meta-data. Returned parameters are in the format of: content type, meta-data, error
Directories
¶
| Path | Synopsis |
|---|---|
|
analyzer
|
|
|
cmd
|
|
|
temporal-lens
command
|
|
|
Code generated by counterfeiter.
|
Code generated by counterfeiter. |
|
Package text handles analyzing textual data for the purpose of meta data extraction
|
Package text handles analyzing textual data for the purpose of meta data extraction |
|
Package utils provides utility tools for lens
|
Package utils provides utility tools for lens |
|
xtractor
|
|
|
planetary
Package planetary handles extraction of consumable data from IPLD objects
|
Package planetary handles extraction of consumable data from IPLD objects |
Click to show internal directories.
Click to hide internal directories.