Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Category ¶
type Category struct {
Name string `json:"name"`
// Identifiers are id's of indexed lens object which match this category
Identifiers []uuid.UUID `json:"object_identifiers"`
}
Category is a particular search category, such as document, pdf, etc..
type Keyword ¶
type Keyword struct {
// Name is the "name" of the keyword, such as storage
Name string `json:"name"`
// LensIdentifiers are the uuids of objects indexed by lens with this particular keyword
LensIdentifiers []uuid.UUID `json:"lens_identifiers"`
}
Keyword is a keyword object stored in badgerds It contains a list of LensIdentifiers, which are the identifiers to a object (ie, ipld) that has been indexed by lens
type MetaData ¶
type MetaData struct {
Summary []string `json:"summary"`
MimeType string `json:"mime_type"`
Category string `json:"category"`
}
MetaData is a piece of meta data from a given object after being lensed
type MetaDataOld ¶
type MetaDataOld struct {
Summary []string `json:"summary"`
}
MetaDataOld is an old metadata object
type Object ¶
type Object struct {
// LensID is the id of this particular object within the lens system
LensID uuid.UUID `json:"lens_id"`
// Name is how you identify the object on it's network. For IPFS/ipld objects, it is the content hash
Name string `json:"name"`
MetaData MetaData `json:"meta_data"`
}
Object is a distributed web object (ie, ipld) that has been indexed by lens
type ObjectOld ¶
type ObjectOld struct {
// LensID is the id of this particular object within the lens system
LensID uuid.UUID `json:"lens_id"`
// Name is how you identify the object on it's network. For IPFS/ipld objects, it is the content hash
Name string `json:"name"`
// Keywords are they words that when search will reveal this content hash
Keywords []string `json:"keywords"`
}
ObjectOld is an old type of lens object
Click to show internal directories.
Click to hide internal directories.