text

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 11, 2018 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package text handles analyzing textual data for the purpose of meta data extraction

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Analyzer

type Analyzer struct {
	TR        *textrank.TextRank
	Rule      parse.Rule
	Language  convert.Language
	Algorithm rank.Algorithm
}

Analyzer is used to analyze and extract meta data from text

func NewTextAnalyzer

func NewTextAnalyzer(useChainAlgorithm bool) *Analyzer

NewTextAnalyzer is used to generate our text analyzer

func (*Analyzer) Clear

func (ta *Analyzer) Clear()

Clear is used to reset the data that textrank is parsing

func (*Analyzer) RetrievePhrases

func (ta *Analyzer) RetrievePhrases(text string) []rank.Phrase

RetrievePhrases is a short wrapper around the FindPhrases function

func (*Analyzer) Summarize

func (ta *Analyzer) Summarize(text string, minWeight float32) []string

Summarize is used to summary a given piece of text

Jump to